@@ -62,7 +62,8 @@ def EVP_BytesToKey(password, key_len, iv_len):
     # so that we make the same key and iv as nodejs version
     if hasattr(password, 'encode'):
         password = password.encode('utf-8')
-    r = cached_keys.get(password, None)
+    cached_key = '%s-%d-%d' % (password, key_len, iv_len)
+    r = cached_keys.get(cached_key, None)
     if r:
         return r
     m = []
@@ -78,7 +79,7 @@ def EVP_BytesToKey(password, key_len, iv_len):
     ms = b''.join(m)
     key = ms[:key_len]
     iv = ms[key_len:key_len + iv_len]
-    cached_keys[password] = (key, iv)
+    cached_keys[cached_key] = (key, iv)
     return key, iv
 
 
@@ -163,3 +164,40 @@ def encrypt_all(password, method, op, data):
     cipher = m(method, key, iv, op)
     result.append(cipher.update(data))
     return b''.join(result)
+
+
+CIPHERS_TO_TEST = [
+    b'aes-128-cfb',
+    b'aes-256-cfb',
+    b'rc4-md5',
+    b'salsa20',
+    b'chacha20',
+    b'table',
+]
+
+
+def test_encryptor():
+    from os import urandom
+    plain = urandom(10240)
+    for method in CIPHERS_TO_TEST:
+        logging.warn(method)
+        encryptor = Encryptor(b'key', method)
+        decryptor = Encryptor(b'key', method)
+        cipher = encryptor.encrypt(plain)
+        plain2 = decryptor.decrypt(cipher)
+        assert plain == plain2
+
+
+def test_encrypt_all():
+    from os import urandom
+    plain = urandom(10240)
+    for method in CIPHERS_TO_TEST:
+        logging.warn(method)
+        cipher = encrypt_all(b'key', method, 1, plain)
+        plain2 = encrypt_all(b'key', method, 0, cipher)
+        assert plain == plain2
+
+
+if __name__ == '__main__':
+    test_encrypt_all()
+    test_encryptor()
